diff --git a/doc/config.rst b/doc/config.rst
index 1d6c5af91be6671db036e03fa5e730e20524b58a..307e5d3e41099284aef71b4d8386e09b33b0e183 100644
--- a/doc/config.rst
+++ b/doc/config.rst
@@ -8,7 +8,7 @@ Preset Configurations
 ---------------------
 
 This module contains preset configurations for baseline CNN architectures and
-datamodules.
+DataModules.
 
 
 .. _mednet.config.models:
@@ -38,9 +38,9 @@ DataModule support
 ==================
 
 Base DataModules and raw data loaders for the various databases currently
-supported in this package, for your reference.  Each pre-configured data module
+supported in this package, for your reference.  Each pre-configured DataModule
 can receive the name of one or more splits as argument to build a fully
-functional data module that can be used in training, prediction or testing.
+functional DataModule that can be used in training, prediction or testing.
 
 .. autosummary::
    :toctree: api/config.datamodules
@@ -67,7 +67,7 @@ Pre-configured DataModules
 
 DataModules provide access to preset pytorch dataloaders for training,
 validating, testing and running prediction tasks.  Each of the pre-configured
-DataModule is based on one (or more) of the :ref:`supported base data modules
+DataModule is based on one (or more) of the :ref:`supported base DataModules
 <mednet.config.datamodules>`.
 
 .. autosummary::
@@ -97,8 +97,8 @@ Cross-validation DataModules
 
 We support cross-validation with precise preset folds.  In this section, you
 will find the configuration for the first fold (fold-0) for all supported
-datamodules.  Nine other folds are available for every configuration (from 1 to
-9), making up 10 folds per supported datamodule.
+DataModules.  Nine other folds are available for every configuration (from 1 to
+9), making up 10 folds per supported DataModule.
 
 
 .. autosummary::
diff --git a/doc/data_model.rst b/doc/data_model.rst
index 1d698abd2e8420e822f1254fd686990f23a4b935..d028419572a6a56145fbe098ea9e20f785327942 100644
--- a/doc/data_model.rst
+++ b/doc/data_model.rst
@@ -64,6 +64,6 @@ before optionally caching in-memory Sample representations. The "raw" representa
 
 DataModule
 ----------
-A datamodule aggregates Splits and RawDataLoaders to provide lightning a known-interface to the complete evaluation protocol (train, validation, prediction and testing)
+A DataModule aggregates Splits and RawDataLoaders to provide lightning a known-interface to the complete evaluation protocol (train, validation, prediction and testing)
 required for a full experiment to take place. It automates control over data loading parallelisation and caching inside our framework,
 providing final access to readily-usable pytorch DataLoaders.
diff --git a/doc/usage/evaluation.rst b/doc/usage/evaluation.rst
index cee0eb457cea665f31f5e9f1ff517482c982d376..4bdd7e843696d396158f0bb31fcce847b6925feb 100644
--- a/doc/usage/evaluation.rst
+++ b/doc/usage/evaluation.rst
@@ -39,7 +39,7 @@ Evaluation
 ----------
 
 In evaluation, we input predictions to generate performance summaries that help analysis of a trained model.
-The generated files are a pdf containing various plots and a table of metrics for each dataset split.
+The generated files are a .pdf containing various plots and a table of metrics for each dataset split.
 Evaluation is done using the :ref:`evaluate command <mednet.cli>` followed by the json file generated during
 the inference step and a threshold.
 
diff --git a/doc/usage/saliency.rst b/doc/usage/saliency.rst
index 8eb3723c0f162ac453a8f331ed33c638ab7f44cc..65074ae5b6585c1a14e5c6c529a632b4679a0479 100644
--- a/doc/usage/saliency.rst
+++ b/doc/usage/saliency.rst
@@ -25,7 +25,7 @@ Several mapping algorithms are available to choose from, which can be specified
 Examples
 ========
 
-Generates saliency maps for all prediction dataloaders on a datamodule,
+Generates saliency maps for all prediction dataloaders on a DataModule,
 using a pre-trained pasa model, and saves them as numpy-pickeled
 objects on the output directory:
 
@@ -53,12 +53,12 @@ Generates visualizations in form of heatmaps from existing saliency maps for a d
 Interpretability
 ----------------
 
-Given a target label, the interpretability step computes the proportional energy and average saliency focus in a datamodule.
+Given a target label, the interpretability step computes the proportional energy and average saliency focus in a DataModule.
 
 The proportional energy is defined as the quantity of activation that lies within the ground truth boxes compared to the total sum of the activations.
 The average saliency focus is the sum of the values of the saliency map over the ground-truth bounding boxes, normalized by the total area covered by all ground-truth bounding boxes.
 
-This requires a datamodule containing human-annotated bounding boxes.
+This requires a DataModule containing human-annotated bounding boxes.
 
 Examples
 ========
@@ -72,7 +72,7 @@ Evaluate the generated saliency maps for their localization performance:
 
 Completeness
 ------------
-The saliency completeness script computes ROAD scores of saliency maps and saves them in a JSON file.
+The saliency completeness script computes ROAD scores of saliency maps and saves them in a .json file.
 
 The ROAD algorithm estimates the explainability (in the completeness sense) of saliency maps by substituting
 relevant pixels in the input image by a local average, re-running prediction on the altered image,
@@ -82,7 +82,7 @@ the importance of such elements in the produced saliency map.
 
 More information can be found in [ROAD-2022]_.
 
-This requires a datamodule containing human-annotated bounding boxes.
+This requires a DataModule containing human-annotated bounding boxes.
 
 Examples
 ========
diff --git a/doc/usage/training.rst b/doc/usage/training.rst
index f071febe86d44b9e7c171203fd77c643f830fbbc..7cd58605e4d6fc05fa2ec0a8564cd05d91f80612 100644
--- a/doc/usage/training.rst
+++ b/doc/usage/training.rst
@@ -71,12 +71,12 @@ Plotting training metrics
 Various metrics are recorded at each epoch during training, such as the execution time, loss and resource usage.
 These are saved in a Tensorboard file, located in a `logs` subdirectory of the training output folder.
 
-Mednet provides a :ref:`train-analysis <mednet.cli>` convenience script that graphs the scalars stored in these files and saves them in a pdf file.
+Mednet provides a :ref:`train-analysis <mednet.cli>` convenience script that graphs the scalars stored in these files and saves them in a .pdf file.
 
 Examples
 ========
 
-Generates a pdf file with plots showing the evolution of logged metrics in time:
+Generates a .pdf file with plots showing the evolution of logged metrics in time:
 
 .. code:: sh
 
diff --git a/src/mednet/config/data/montgomery/datamodule.py b/src/mednet/config/data/montgomery/datamodule.py
index dbe43cc6a8f378d8baeb6b8e9f5c2d24ebf7c491..c7aac4c821aca5b9a45cf11fff9e630c80e5e974 100644
--- a/src/mednet/config/data/montgomery/datamodule.py
+++ b/src/mednet/config/data/montgomery/datamodule.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection.
+"""Montgomery DataModule for TB detection.
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 """
@@ -95,7 +95,7 @@ def make_split(basename: str) -> DatabaseSplit:
 
 
 class DataModule(CachingDataModule):
-    """Montgomery datamodule for TB detection.
+    """Montgomery DataModule for TB detection.
 
     The standard digital image database for Tuberculosis was created by the National
     Library of Medicine, Maryland, USA in collaboration with Shenzhen No.3 People’s
diff --git a/src/mednet/config/data/montgomery/default.py b/src/mednet/config/data/montgomery/default.py
index edd014e8231350bb86e1e9fe28ab48409665c10c..afb62d5db67dd2bf402fb052a884284106cc3ec1 100644
--- a/src/mednet/config/data/montgomery/default.py
+++ b/src/mednet/config/data/montgomery/default.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection.
+"""Montgomery DataModule for TB detection.
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_0.py b/src/mednet/config/data/montgomery/fold_0.py
index 6d62330303dc33c2d220133b8a1677ad3499afef..02597fad834853a69612c89096ee66a2de47378b 100644
--- a/src/mednet/config/data/montgomery/fold_0.py
+++ b/src/mednet/config/data/montgomery/fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 0).
+"""Montgomery DataModule for TB detection (cross validation fold 0).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_1.py b/src/mednet/config/data/montgomery/fold_1.py
index 649f625f75266727e7beec87a5d226d959ce0798..5aff117fafeba1aab3508e8fcec94408ef19ac68 100644
--- a/src/mednet/config/data/montgomery/fold_1.py
+++ b/src/mednet/config/data/montgomery/fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 1).
+"""Montgomery DataModule for TB detection (cross validation fold 1).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_2.py b/src/mednet/config/data/montgomery/fold_2.py
index 28f55b902a5f675f01b69574089820bbf060eaaa..879562db0df7f165e66a65eaffcd0c825ccb678d 100644
--- a/src/mednet/config/data/montgomery/fold_2.py
+++ b/src/mednet/config/data/montgomery/fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 2).
+"""Montgomery DataModule for TB detection (cross validation fold 2).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_3.py b/src/mednet/config/data/montgomery/fold_3.py
index e357f27efb0fe79bc313112a044649c4bfb11d7a..1e8a31e002cbda5a722e80143045b569f51ee327 100644
--- a/src/mednet/config/data/montgomery/fold_3.py
+++ b/src/mednet/config/data/montgomery/fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 3).
+"""Montgomery DataModule for TB detection (cross validation fold 3).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_4.py b/src/mednet/config/data/montgomery/fold_4.py
index 57402c018068cf7b24f29ce61442e73067148c4c..eb396a7a2a44aae2cc8fb21dd496ff9f1346461a 100644
--- a/src/mednet/config/data/montgomery/fold_4.py
+++ b/src/mednet/config/data/montgomery/fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 4).
+"""Montgomery DataModule for TB detection (cross validation fold 4).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_5.py b/src/mednet/config/data/montgomery/fold_5.py
index 30b172411d3f9e726ad458bc85540fabdaddff5f..b3620674900c81634d5d17c577dbe240cc2b8729 100644
--- a/src/mednet/config/data/montgomery/fold_5.py
+++ b/src/mednet/config/data/montgomery/fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 5).
+"""Montgomery DataModule for TB detection (cross validation fold 5).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_6.py b/src/mednet/config/data/montgomery/fold_6.py
index d8a2a8e2ff934c02a40480f0f6709425277dcbfc..298fc9c5125e45453e1cda5c9637283a3c3a575f 100644
--- a/src/mednet/config/data/montgomery/fold_6.py
+++ b/src/mednet/config/data/montgomery/fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 6).
+"""Montgomery DataModule for TB detection (cross validation fold 6).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_7.py b/src/mednet/config/data/montgomery/fold_7.py
index 86d16e0c12ce0423454f4f32f69b99830f2b40b2..93ca3c00c8bdceed09bc911c8451873fcec2e56f 100644
--- a/src/mednet/config/data/montgomery/fold_7.py
+++ b/src/mednet/config/data/montgomery/fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 7).
+"""Montgomery DataModule for TB detection (cross validation fold 7).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_8.py b/src/mednet/config/data/montgomery/fold_8.py
index 67a337d2fcc8b7cda4fe888f63cbe253e7f0e933..05b2b1d14e1c322e4ae333d9bca984bbe425f33d 100644
--- a/src/mednet/config/data/montgomery/fold_8.py
+++ b/src/mednet/config/data/montgomery/fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 8).
+"""Montgomery DataModule for TB detection (cross validation fold 8).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery/fold_9.py b/src/mednet/config/data/montgomery/fold_9.py
index 032cdbfef25fc2b142910b1d754417856bcebefb..ac6539d960584394e298fb12013aff3827e2b2a2 100644
--- a/src/mednet/config/data/montgomery/fold_9.py
+++ b/src/mednet/config/data/montgomery/fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Montgomery datamodule for TB detection (cross validation fold 9).
+"""Montgomery DataModule for TB detection (cross validation fold 9).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/montgomery_shenzhen/datamodule.py b/src/mednet/config/data/montgomery_shenzhen/datamodule.py
index 9699f19d7fde69565d70c8767538d0136c325ff5..06100561aa9f58e9ee0818f3d7bc61e88ae1dc17 100644
--- a/src/mednet/config/data/montgomery_shenzhen/datamodule.py
+++ b/src/mednet/config/data/montgomery_shenzhen/datamodule.py
@@ -10,7 +10,7 @@ from ..shenzhen.datamodule import make_split as make_shenzhen_split
 
 
 class DataModule(ConcatDataModule):
-    """Aggregated datamodule composed of Montgomery and Shenzhen datasets."""
+    """Aggregated DataModule composed of Montgomery and Shenzhen datasets."""
 
     def __init__(self, split_filename: str):
         montgomery_loader = MontgomeryLoader()
diff --git a/src/mednet/config/data/montgomery_shenzhen/default.py b/src/mednet/config/data/montgomery_shenzhen/default.py
index 106bb415262932cd4fcfa954322f6f8d7353f554..24dcc4b3b21190f86e04288caec1575bebdfd11d 100644
--- a/src/mednet/config/data/montgomery_shenzhen/default.py
+++ b/src/mednet/config/data/montgomery_shenzhen/default.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (default
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (default
 split).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_0.py b/src/mednet/config/data/montgomery_shenzhen/fold_0.py
index d03c9c544afd5ec5a3abec3c17984d5e571c3bec..8d3191561980e3b31d809061257ceacf757cca9e 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_0.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 0).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_1.py b/src/mednet/config/data/montgomery_shenzhen/fold_1.py
index 948a75b07de9fe76df372964fec4c147063fcc8d..a9095a0db8a69f056576d57d89f2fcddaf06b9ab 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_1.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 1).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_2.py b/src/mednet/config/data/montgomery_shenzhen/fold_2.py
index c627fa2253cf034a402135f8575ae99042487682..79203be407919e4485836981e7e34b546003630a 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_2.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 2).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_3.py b/src/mednet/config/data/montgomery_shenzhen/fold_3.py
index 9ba252f3114625f05b21cbbad1a420c5ea9dc834..fb3114fd681d8174891dbd95bc8f5f9f83743c92 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_3.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 3).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_4.py b/src/mednet/config/data/montgomery_shenzhen/fold_4.py
index 720a3adc225b864c104a2cb8bd77250fde45e7f3..24cbc745242824ef96366887a1ce71ad9920f962 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_4.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 4).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_5.py b/src/mednet/config/data/montgomery_shenzhen/fold_5.py
index c784a4ea01bfeacb2140b7ffdff5d06a618865ab..887cc682989d94d480d79776935381ed67111d8a 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_5.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 5).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_6.py b/src/mednet/config/data/montgomery_shenzhen/fold_6.py
index eaa4647240a73b2ae6d9b8b4e5ce7a76f2a6ad16..81a8a906366a6f60a433ff044441e9274d059eb2 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_6.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 6).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_7.py b/src/mednet/config/data/montgomery_shenzhen/fold_7.py
index 7a6dd33b281e0c41b0823dacba70d443e19310d2..298f19616a867b9395ae3233d2d205fd1e487f93 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_7.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 7).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_8.py b/src/mednet/config/data/montgomery_shenzhen/fold_8.py
index 8f295426865d2523caffac09e52f1d67fd138379..b8c2ff10e351aee4525827ac8a70a91e9c21619b 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_8.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 8).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen/fold_9.py b/src/mednet/config/data/montgomery_shenzhen/fold_9.py
index 1ec041b8c56923b60eb744f744dfe579bc3fd434..30528cae581a3dbb274cec9511b0c8ab23c3d687 100644
--- a/src/mednet/config/data/montgomery_shenzhen/fold_9.py
+++ b/src/mednet/config/data/montgomery_shenzhen/fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery and Shenzhen datasets (cross
+"""Aggregated DataModule composed of Montgomery and Shenzhen datasets (cross
 validation fold 9).
 
 See :py:class:`.montgomery_shenzhen.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/datamodule.py b/src/mednet/config/data/montgomery_shenzhen_indian/datamodule.py
index 2001857379da827cc03c0bf7a1a21466cadc3c79..303bf5e714e8824ddc7fb0d814425a834301b9cc 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/datamodule.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/datamodule.py
@@ -1,7 +1,7 @@
 # Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian
 datasets."""
 
 from ....data.datamodule import ConcatDataModule
@@ -14,7 +14,7 @@ from ..shenzhen.datamodule import make_split as make_shenzhen_split
 
 
 class DataModule(ConcatDataModule):
-    """Aggregated datamodule composed of Montgomery, Shenzhen and Indian
+    """Aggregated DataModule composed of Montgomery, Shenzhen and Indian
     datasets."""
 
     def __init__(self, split_filename: str):
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/default.py b/src/mednet/config/data/montgomery_shenzhen_indian/default.py
index a1ac8047aa6f526b68e5b4df03a87a55de98b140..38fca2a93cf5860978397bd737ad7b8cde611704 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/default.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/default.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets.
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets.
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
 details.
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_0.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_0.py
index aecbbd107ab4a4d8e1bbe15b318deb8f58fe1238..83d67fe3506611d6d4b1a4bf352c6faa27ad7b08 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_0.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 0).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_1.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_1.py
index bef0e4aee628a0a22f1b49a5052ee9124d6a2ad9..a44b6a68c73942700c4a86165bce53d12a854680 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_1.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 1).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_2.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_2.py
index 4a75d3329902f0ca439bf17bafea950f5bc23de8..5dac88e8d3a965da37da6f1c76a52721779fad9c 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_2.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 2).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_3.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_3.py
index a85428cb606030252413c841b2849b128a98713c..8fe095a351874f51457b031ff71e91876177ae7d 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_3.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 3).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_4.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_4.py
index 857a5b622fbe5f814b8aec418fc631297632083d..6524f589f7bd67b979868ae8b51613da45df6cfd 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_4.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 4).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_5.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_5.py
index 58ac206ca6b30af085b4c7d742757414267e934a..8b0acbe6e6fdf7b5739fa2ddb45b5daadb1d1283 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_5.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 5).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_6.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_6.py
index db77fcc0fcb92446a7220c806fa63a6b7b22bf4b..d8b565adfb2e08cd2891593e74798c15187dadbf 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_6.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 6).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_7.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_7.py
index aa7f79e5d7d18d7676953ec208da8fc7acddbc54..248f6621cd9cfb048007889618c672ada29e9398 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_7.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 7).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_8.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_8.py
index 31fca75024ac528cc04879fbddc3150367026239..41c5e5cab86184e74eaf924612ee04f7c672855e 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_8.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 8).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian/fold_9.py b/src/mednet/config/data/montgomery_shenzhen_indian/fold_9.py
index 54c9a07e798db588cd2857331485302fd770af76..f658cf37c0c0cc47fb3fc92ab3807af12998f0a4 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian/fold_9.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian/fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen and Indian datasets
+"""Aggregated DataModule composed of Montgomery, Shenzhen and Indian datasets
 (cross validation fold 9).
 
 See :py:class:`.montgomery_shenzhen_indian.datamodule.DataModule` for technical details.
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_padchest/datamodule.py b/src/mednet/config/data/montgomery_shenzhen_indian_padchest/datamodule.py
index 8414ad94077aa995b26ad79bf141d5d2c69ee914..ee111c03f20cb337198a02d38fa8582406cb78ad 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_padchest/datamodule.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_padchest/datamodule.py
@@ -1,7 +1,7 @@
 # Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and PadChest
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and PadChest
 datasets."""
 
 from ....data.datamodule import ConcatDataModule
@@ -16,7 +16,7 @@ from ..shenzhen.datamodule import make_split as make_shenzhen_split
 
 
 class DataModule(ConcatDataModule):
-    """Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and
+    """Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and
     PadChest datasets."""
 
     def __init__(self, split_filename: str, padchest_split_filename: str):
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/datamodule.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/datamodule.py
index 783f7251a6cf0f9bfd384d829bf94050bb8fce46..f83e44042dcbc29102389368dfbdded96acc6a0e 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/datamodule.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/datamodule.py
@@ -1,7 +1,7 @@
 # Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets."""
 
 from ....data.datamodule import ConcatDataModule
@@ -16,7 +16,7 @@ from ..tbx11k.datamodule import make_split as make_tbx11k_split
 
 
 class DataModule(ConcatDataModule):
-    """Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and
+    """Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and
     TBX11k datasets."""
 
     def __init__(self, split_filename: str, tbx11_split_filename: str):
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_0.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_0.py
index 88cd03e2c8f11c86490864fb1c4362702796fec0..a866e229c5220058d5f838288eed1e44406a288d 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_0.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 0).
 
 This remix dataset combines ``fold-0`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_1.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_1.py
index 10f57c42bcc895ef47e447150859cbb7665f3d43..cc9d26ce771ee1833111e665ab102efbbf077120 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_1.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 1).
 
 This remix dataset combines ``fold-1`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_2.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_2.py
index 6ec20140b059eb0f98c60341479d0ebefd318ca7..c9f77703b1ec5363ca2431bbf4d39ac009dbc32e 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_2.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 2).
 
 This remix dataset combines ``fold-2`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_3.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_3.py
index 569ed8017632595bd2627a46571587f6bfb0f898..639ac053f3b34d9b4278d51b6bed76b0e6c77c51 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_3.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 3).
 
 This remix dataset combines ``fold-3`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_4.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_4.py
index 04a74cd35ccb133634d8ca5db18936861ef2eab0..b08f0588e44a040ad4dbc3c9c918e8a82b260023 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_4.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 4).
 
 This remix dataset combines ``fold-4`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_5.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_5.py
index b528a7b6799f76da1cb8c50c8071f088f6c082e2..7cfd77253141d959731bbb857cf04d7b090b2b53 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_5.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 5).
 
 This remix dataset combines ``fold-5`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_6.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_6.py
index fdf55b4274f8329dda7aa28f654bde654df2fc33..c8341e7e45ea8411f51ece99b4accb6b851a5151 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_6.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 6).
 
 This remix dataset combines ``fold-6`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_7.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_7.py
index 833d2c04b2b8699e5143f9ad99231440133ff9bc..9f9b19d54bbf0c8c5211794e86d30d2ba92b2099 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_7.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 7).
 
 This remix dataset combines ``fold-7`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_8.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_8.py
index a0dd7e822386ea260808a0ead9475d78136ce91e..a212479358eb129cc64baadc45865519594e9fe9 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_8.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 8).
 
 This remix dataset combines ``fold-8`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_9.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_9.py
index ea00d8ecf7726c308fc9007031ab7af21b5f4008..b2dff65bd393055eec1135a922339cbc3ee09832 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_9.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 9).
 
 This remix dataset combines ``fold-9`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_healthy_vs_atb.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_healthy_vs_atb.py
index 278ac64eeadc31a36b5df90ee5c76ccdc92e7a09..0f4d1393f0fb0973cf7b57cb3312f98c3bafd164 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_healthy_vs_atb.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v1_healthy_vs_atb.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (v1-healthy-vs-atb).
 
 This remix dataset combines the ``default`` split from Montgomery, Shenzhen,
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_0.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_0.py
index 022824a1795eb56bd7e95ccf7845b86452020098..93fe390dd8de655a89f4cdb8f74382734def4182 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_0.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 0).
 
 This remix dataset combines ``fold-0`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_1.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_1.py
index e48e83e797e6f69942d7345d387f5e50d2946c67..0ed16e701663a05756d4c44ce2e84d1d44ca56dc 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_1.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 1).
 
 This remix dataset combines ``fold-1`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_2.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_2.py
index 1e8f38fbd000c8e026c5451abfceffe3338bbd00..2ff42bcd694ec2142f114666d5452fa5f4361b1f 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_2.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 2).
 
 This remix dataset combines ``fold-2`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_3.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_3.py
index 553ea54762ee64a672a02f9e7478ef2bd21b2405..dc4b1a4c5fed9e272fe332432a5405f866a3cbde 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_3.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 3).
 
 This remix dataset combines ``fold-3`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_4.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_4.py
index 672c9bbe3a09c88b6b50ac27d6dccbbf594a2e82..55113094b5095463ba083cc2b12d72acde53b2fc 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_4.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 4).
 
 This remix dataset combines ``fold-4`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_5.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_5.py
index b7b3c5eddaa9daf3b1181b422667c48991d77628..0bffb95e6ff791c8d95adcea66ffe5d49619e821 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_5.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 5).
 
 This remix dataset combines ``fold-5`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_6.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_6.py
index e30017374dcb6b78bb9b829e5956878666551f05..a5507999d10facdb2f000637a3e47cc028ee9233 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_6.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 6).
 
 This remix dataset combines ``fold-6`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_7.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_7.py
index 4f3b3e9167c998306e4836840f51fded3de5963b..944c1eb9bc18f6e88093a4ab3a3ea2ac2d565b07 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_7.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 7).
 
 This remix dataset combines ``fold-7`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_8.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_8.py
index afdb0f75625348df60c5b01760cd541d684c2dae..db5331c6b84d887bb2aa1e98d325d434853e1825 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_8.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 8).
 
 This remix dataset combines ``fold-8`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_9.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_9.py
index 31b1e4400fd22674df823791d404fc3d0817e347..898a46aea2dddcfc0eafc15f06b0b77b15f6f806 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_9.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (cross-validation fold 9).
 
 This remix dataset combines ``fold-9`` from Montgomery, Shenzhen, and Indian
diff --git a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_others_vs_atb.py b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_others_vs_atb.py
index 9dca260604e2c65e85f9a1b06cd96fd853560e3d..b0bce0aeed787d7d3ad9dc23dba9321d3e9785a5 100644
--- a/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_others_vs_atb.py
+++ b/src/mednet/config/data/montgomery_shenzhen_indian_tbx11k/v2_others_vs_atb.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Aggregated datamodule composed of Montgomery, Shenzhen, Indian, and TBX11k
+"""Aggregated DataModule composed of Montgomery, Shenzhen, Indian, and TBX11k
 datasets (v2-others-vs-atb).
 
 This remix dataset combines the ``default`` split from Montgomery, Shenzhen,
diff --git a/src/mednet/config/data/nih_cxr14/cardiomegaly.py b/src/mednet/config/data/nih_cxr14/cardiomegaly.py
index 8be9fde0b963123a6becccdf3c850ea193826371..255be72e79840527a0e401ac8c5e048033038a2a 100644
--- a/src/mednet/config/data/nih_cxr14/cardiomegaly.py
+++ b/src/mednet/config/data/nih_cxr14/cardiomegaly.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""NIH CXR14 (relabeled) datamodule for computer-aided diagnosis (cardiomegaly
+"""NIH CXR14 (relabeled) DataModule for computer-aided diagnosis (cardiomegaly
 split).
 
 Database reference: [NIH-CXR14-2017]_
diff --git a/src/mednet/config/data/nih_cxr14/datamodule.py b/src/mednet/config/data/nih_cxr14/datamodule.py
index 4971814c3e391726dfb4fd2012e749f6a7a65beb..7c3edcef9850b1f79a8449ca06715e68a827d500 100644
--- a/src/mednet/config/data/nih_cxr14/datamodule.py
+++ b/src/mednet/config/data/nih_cxr14/datamodule.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""NIH CXR14 (relabeled) datamodule for computer-aided diagnosis.
+"""NIH CXR14 (relabeled) DataModule for computer-aided diagnosis.
 
 Database reference: [NIH-CXR14-2017]_
 """
@@ -129,7 +129,7 @@ def make_split(basename: str) -> DatabaseSplit:
 
 
 class DataModule(CachingDataModule):
-    """NIH CXR14 (relabeled) datamodule for computer-aided diagnosis.
+    """NIH CXR14 (relabeled) DataModule for computer-aided diagnosis.
 
     This dataset was extracted from the clinical PACS database at the National
     Institutes of Health Clinical Center (USA) and represents 60% of all their
diff --git a/src/mednet/config/data/nih_cxr14/default.py b/src/mednet/config/data/nih_cxr14/default.py
index 2fa797be4371e78115516c22545a9c9d457fdc97..8c15cd71dd85ea5c3e9a9704ab81a877d926633f 100644
--- a/src/mednet/config/data/nih_cxr14/default.py
+++ b/src/mednet/config/data/nih_cxr14/default.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""NIH CXR14 (relabeled) datamodule (``default`` protocol).
+"""NIH CXR14 (relabeled) DataModule (``default`` protocol).
 
 * Training samples: 98637
 * Validation samples: 6350
diff --git a/src/mednet/config/data/shenzhen/datamodule.py b/src/mednet/config/data/shenzhen/datamodule.py
index 4a210cfe4507e3ad81af6a402fbc420697ca734a..1510220275a61cc407aa4f342de403f3e950d85d 100644
--- a/src/mednet/config/data/shenzhen/datamodule.py
+++ b/src/mednet/config/data/shenzhen/datamodule.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis.
+"""Shenzhen DataModule for computer-aided diagnosis.
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 """
@@ -98,7 +98,7 @@ def make_split(basename: str) -> DatabaseSplit:
 
 
 class DataModule(CachingDataModule):
-    """Shenzhen datamodule for computer-aided diagnosis.
+    """Shenzhen DataModule for computer-aided diagnosis.
 
     The standard digital image database for Tuberculosis was created by the National
     Library of Medicine, Maryland, USA in collaboration with Shenzhen No.3 People’s
diff --git a/src/mednet/config/data/shenzhen/fold_0.py b/src/mednet/config/data/shenzhen/fold_0.py
index 17ab27e504e1467da338d22a860a7a1de7fb9bc8..218211fa31368d1abeb869b7f6dae58900c0effc 100644
--- a/src/mednet/config/data/shenzhen/fold_0.py
+++ b/src/mednet/config/data/shenzhen/fold_0.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 0).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 0).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_1.py b/src/mednet/config/data/shenzhen/fold_1.py
index 61ea13aa984be81b5f94f740c4848f374659d35f..cee2fd624dc617291aa9cc0a730eeb94a4a0a58c 100644
--- a/src/mednet/config/data/shenzhen/fold_1.py
+++ b/src/mednet/config/data/shenzhen/fold_1.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 1).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 1).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_2.py b/src/mednet/config/data/shenzhen/fold_2.py
index edb9247796cb6baa1f1cea0b72ad8ac3728b1f48..1373a64ccc1ecbbe3104e659aa6739bb6684450f 100644
--- a/src/mednet/config/data/shenzhen/fold_2.py
+++ b/src/mednet/config/data/shenzhen/fold_2.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 2).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 2).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_3.py b/src/mednet/config/data/shenzhen/fold_3.py
index 618008481b7c2892448d1dbe205cda68e33764b7..8fa1c4c2552d240126e4e502e0a74dd5366a8ca3 100644
--- a/src/mednet/config/data/shenzhen/fold_3.py
+++ b/src/mednet/config/data/shenzhen/fold_3.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 3).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 3).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_4.py b/src/mednet/config/data/shenzhen/fold_4.py
index 478af2ee758e675722d0578a316a33f7a0e47898..3998c2d2246bd98e6ec20a591dd84682b2bd0d12 100644
--- a/src/mednet/config/data/shenzhen/fold_4.py
+++ b/src/mednet/config/data/shenzhen/fold_4.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 4).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 4).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_5.py b/src/mednet/config/data/shenzhen/fold_5.py
index 21dcf8ff1ec64781172cb01976e4f7eca2b79d1f..71452ef25039f7195784e29f35af3d7e1bf06260 100644
--- a/src/mednet/config/data/shenzhen/fold_5.py
+++ b/src/mednet/config/data/shenzhen/fold_5.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 5).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 5).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_6.py b/src/mednet/config/data/shenzhen/fold_6.py
index fbc6aac8cb40ca898790040edcffda62999ae3e9..69a51ccef6dc87bbb66cbd89d92a26a472f48ce6 100644
--- a/src/mednet/config/data/shenzhen/fold_6.py
+++ b/src/mednet/config/data/shenzhen/fold_6.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 6).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 6).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_7.py b/src/mednet/config/data/shenzhen/fold_7.py
index 204f7b0b2cc981229ba4252acd4ca0fb99983f04..619a28d0625a0344053f01d1c25d96f6a2549482 100644
--- a/src/mednet/config/data/shenzhen/fold_7.py
+++ b/src/mednet/config/data/shenzhen/fold_7.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 7).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 7).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_8.py b/src/mednet/config/data/shenzhen/fold_8.py
index 3679fa18b58af7f5eba68d5e41eca06fcbfa5232..1eb4278a7f3c491914d98038018ea9383bf4d8e7 100644
--- a/src/mednet/config/data/shenzhen/fold_8.py
+++ b/src/mednet/config/data/shenzhen/fold_8.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 8).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 8).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/config/data/shenzhen/fold_9.py b/src/mednet/config/data/shenzhen/fold_9.py
index 32afdbd8b786f94597198f3bf99ac38a9e6773a9..c112edf906ffda4eb03bdc6414c95e5d972a27be 100644
--- a/src/mednet/config/data/shenzhen/fold_9.py
+++ b/src/mednet/config/data/shenzhen/fold_9.py
@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-"""Shenzhen datamodule for computer-aided diagnosis (cross validation fold 9).
+"""Shenzhen DataModule for computer-aided diagnosis (cross validation fold 9).
 
 Database reference: [MONTGOMERY-SHENZHEN-2014]_
 
diff --git a/src/mednet/data/datamodule.py b/src/mednet/data/datamodule.py
index 758f0ef0b274d6f59755fa3546e1c7ae777a83d5..539bd6215c16c0ef266c8c747d5820f49eb0e12b 100644
--- a/src/mednet/data/datamodule.py
+++ b/src/mednet/data/datamodule.py
@@ -390,7 +390,7 @@ def _make_balanced_random_sampler(
 
 
 class ConcatDataModule(lightning.LightningDataModule):
-    """A conveninent data module with dictionary split loading, mini- batching,
+    """A conveninent DataModule with dictionary split loading, mini- batching,
     parallelisation and caching, all in one.
 
     Instances of this class can load and concatenate an arbitrary number of
@@ -399,7 +399,7 @@ class ConcatDataModule(lightning.LightningDataModule):
     stores the data in associated CPU memory, which can improve data serving
     while training and evaluating models.
 
-    This datamodule defines basic operations to handle data loading and
+    This DataModule defines basic operations to handle data loading and
     mini-batch handling within this package's framework.  It can return
     :py:class:`torch.utils.data.DataLoader` objects for training, validation,
     prediction and testing conditions.  Parallelisation is handled by a simple
@@ -582,8 +582,8 @@ class ConcatDataModule(lightning.LightningDataModule):
         A list of transforms (torch modules) that will be applied after
         raw-data-loading. and just before data is fed into the model or
         eventual data-augmentation transformations for all data loaders
-        produced by this data module.  This part of the pipeline
-        receives data as output by the raw-data-loader, or model-related
+        produced by this DataModule.  This part of the pipeline receives
+        data as output by the raw-data-loader, or model-related
         transforms (e.g. resize adaptions), if any is specified.  If
         data is cached, it is cached **after** model-transforms are
         applied, as that is a potential memory saver (e.g., if it
@@ -873,9 +873,9 @@ class ConcatDataModule(lightning.LightningDataModule):
 
 
 class CachingDataModule(ConcatDataModule):
-    """A simplified version of our data module for a single split.
+    """A simplified version of our DataModule for a single split.
 
-    Apart from construction, the behaviour of this data module is very similar
+    Apart from construction, the behaviour of this DataModule is very similar
     to its simpler counterpart, serving training, validation and test sets.
 
     Parameters
diff --git a/src/mednet/data/split.py b/src/mednet/data/split.py
index 634c1b65b710ca740d2f097f2d57efa8648e990d..7dc61f22111b1460e1e5125ca32aeb9574f00042 100644
--- a/src/mednet/data/split.py
+++ b/src/mednet/data/split.py
@@ -62,7 +62,7 @@ class JSONDatabaseSplit(DatabaseSplit):
     Parameters
     ----------
     path
-        Absolute path to a JSON formatted file containing the database split to be
+        Absolute path to a .json formatted file containing the database split to be
         recognized by this object.
     """
 
@@ -75,7 +75,7 @@ class JSONDatabaseSplit(DatabaseSplit):
     def _datasets(self) -> DatabaseSplit:
         """Datasets in a split.
 
-        The first call to this (cached) property will trigger full JSON file
+        The first call to this (cached) property will trigger full .json file
         loading from disk.  Subsequent calls will be cached.
 
         Returns
diff --git a/src/mednet/engine/saliency/completeness.py b/src/mednet/engine/saliency/completeness.py
index 655cdedc72b27c499ba29c1cd952a0b58b35d8f2..c9a961f7fe6d52ec3c65526fe6347485078671ac 100644
--- a/src/mednet/engine/saliency/completeness.py
+++ b/src/mednet/engine/saliency/completeness.py
@@ -203,7 +203,7 @@ def run(
     percentiles: typing.Sequence[int],
     parallel: int,
 ) -> dict[str, list[typing.Any]]:
-    """Evaluates ROAD scores for all samples in a datamodule.
+    """Evaluates ROAD scores for all samples in a DataModule.
 
     The ROAD algorithm was first described in [ROAD-2022]_. It estimates
     explainability (in the completeness sense) of saliency maps by substituting
@@ -225,7 +225,7 @@ def run(
     model
         Neural network model (e.g. pasa).
     datamodule
-        The lightning datamodule to iterate on.
+        The lightning DataModule to iterate on.
     device_manager
         An internal device representation, to be used for training and
         validation.  This representation can be converted into a pytorch device
@@ -254,7 +254,7 @@ def run(
     Returns
     -------
     dict[str, list[typing.Any]]
-        A dictionary where keys are dataset names in the provide datamodule,
+        A dictionary where keys are dataset names in the provide DataModule,
         and values are lists containing sample information alongside metrics
         calculated:
 
diff --git a/src/mednet/engine/saliency/generator.py b/src/mednet/engine/saliency/generator.py
index 2096adc1a45d3c69642ff8ec6bd3e738bdec12f1..72b53d5131580575787d119c12faed6f4999045d 100644
--- a/src/mednet/engine/saliency/generator.py
+++ b/src/mednet/engine/saliency/generator.py
@@ -125,7 +125,7 @@ def run(
     model
         Neural network model (e.g. pasa).
     datamodule
-        The lightning datamodule to iterate on.
+        The lightning DataModule to iterate on.
     device_manager
         An internal device representation, to be used for training and
         validation.  This representation can be converted into a pytorch device
diff --git a/src/mednet/engine/saliency/interpretability.py b/src/mednet/engine/saliency/interpretability.py
index b18cfe95fa71852916268e5c0cbb47d7653688f0..6611d157f1401a11a7a1abca799dd5d71053e905 100644
--- a/src/mednet/engine/saliency/interpretability.py
+++ b/src/mednet/engine/saliency/interpretability.py
@@ -388,7 +388,7 @@ def run(
     datamodule: lightning.pytorch.LightningDataModule,
 ) -> dict[str, list[typing.Any]]:
     """Computes the proportional energy and average saliency focus for a given
-    target label in a datamodule.
+    target label in a DataModule.
 
     Parameters
     ---------
@@ -399,12 +399,12 @@ def run(
         The label to target for evaluating interpretability metrics. Samples
         contining any other label are ignored.
     datamodule
-        The lightning datamodule to iterate on.
+        The lightning DataModule to iterate on.
 
     Returns
     -------
     dict[str, list[typing.Any]]
-        A dictionary where keys are dataset names in the provided datamodule,
+        A dictionary where keys are dataset names in the provided DataModule,
         and values are lists containing sample information alongside metrics
         calculated:
 
diff --git a/src/mednet/engine/saliency/viewer.py b/src/mednet/engine/saliency/viewer.py
index 184a586d7d249cec91c69145e52006b4fbbd1c52..4e4c6890dfc6c6d1fba4de5427a5e7a15a1a2f1b 100644
--- a/src/mednet/engine/saliency/viewer.py
+++ b/src/mednet/engine/saliency/viewer.py
@@ -200,7 +200,7 @@ def run(
     Parameters
     ----------
     datamodule
-        The lightning datamodule to iterate on.
+        The Lightning DataModule to iterate on.
     input_folder
         Directory in which the saliency maps are stored for a specific
         visualization type.
diff --git a/src/mednet/engine/trainer.py b/src/mednet/engine/trainer.py
index 3c3deeee2eacb8fa2d81e6a0b5836d6906168a60..c338d7f42fa1bbb274abe974a761b344a68f2cdf 100644
--- a/src/mednet/engine/trainer.py
+++ b/src/mednet/engine/trainer.py
@@ -125,7 +125,7 @@ def run(
     model
         Neural network model (e.g. pasa).
     datamodule
-        The lightning datamodule to use for training **and** validation.
+        The lightning DataModule to use for training **and** validation.
     validation_period
         Number of epochs after which validation happens.  By default, we run
         validation after every training epoch (period=1).  You can change this
diff --git a/src/mednet/scripts/evaluate.py b/src/mednet/scripts/evaluate.py
index ec8365b95a625b3be30e040d1c514ae78003170f..25976eef935645da93d3c0e377b31ac67175554c 100644
--- a/src/mednet/scripts/evaluate.py
+++ b/src/mednet/scripts/evaluate.py
@@ -38,7 +38,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--predictions",
     "-p",
-    help="Path where predictions are currently stored",
+    help="Directory in which predictions are currently stored",
     required=True,
     type=click.Path(
         file_okay=True, dir_okay=False, writable=True, path_type=pathlib.Path
@@ -48,7 +48,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output-folder",
     "-o",
-    help="Path where to store the analysis result (created if does not exist)",
+    help="Directory in which to store the analysis result (created if does not exist)",
     required=False,
     default="results",
     type=click.Path(file_okay=False, dir_okay=True, path_type=pathlib.Path),
diff --git a/src/mednet/scripts/predict.py b/src/mednet/scripts/predict.py
index c684ed9514c83f980bfa3b65387ed01164a5bc9a..34cf93aa129194556a78414eae0d13a0668f7f88 100644
--- a/src/mednet/scripts/predict.py
+++ b/src/mednet/scripts/predict.py
@@ -19,7 +19,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
     cls=ConfigCommand,
     epilog="""Examples:
 
-1. Runs prediction on an existing datamodule configuration:
+1. Runs prediction on an existing DataModule configuration:
 
    .. code:: sh
 
@@ -36,8 +36,8 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output",
     "-o",
-    help="""Path where to store the JSON predictions for all samples in the
-    input datamodule (leading directories are created if they do not
+    help="""Path to a .json file in which to save predictions for all samples in the
+    input DataModule (leading directories are created if they do not
     exist).""",
     required=True,
     default="results",
@@ -57,9 +57,9 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--datamodule",
     "-d",
-    help="""A lightning data module that will be asked for prediction data
-    loaders. Typically, this includes all configured splits in a datamodule,
-    however this is not a requirement.  A datamodule that returns a single
+    help="""A lightning DataModule that will be asked for prediction data
+    loaders. Typically, this includes all configured splits in a DataModule,
+    however this is not a requirement.  A DataModule that returns a single
     dataloader for prediction (wrapped in a dictionary) is acceptable.""",
     required=True,
     cls=ResourceOption,
diff --git a/src/mednet/scripts/saliency/completeness.py b/src/mednet/scripts/saliency/completeness.py
index 62072612e4b5ae6b6ad6d7d3b1f1c72521453450..1d9d7172e9291393f004f6d801387e8f7670834e 100644
--- a/src/mednet/scripts/saliency/completeness.py
+++ b/src/mednet/scripts/saliency/completeness.py
@@ -41,17 +41,17 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--datamodule",
     "-d",
-    help="""A lightning data module that will be asked for prediction data
-    loaders. Typically, this includes all configured splits in a datamodule,
-    however this is not a requirement.  A datamodule that returns a single
-    dataloader for prediction (wrapped in a dictionary) is acceptable.""",
+    help="""A lightning DataModule that will be asked for prediction DataLoaders.
+    Typically, this includes all configured splits in a DataModule,
+    however this is not a requirement.  A DataModule that returns a single
+    DataLoader for prediction (wrapped in a dictionary) is acceptable.""",
     required=True,
     cls=ResourceOption,
 )
 @click.option(
     "--output-json",
     "-o",
-    help="""Path where to store the output JSON file containing all
+    help="""Directory in which to store the output .json file containing all
     measures.""",
     required=True,
     type=click.Path(
@@ -188,15 +188,15 @@ def completeness(
     2023, this measurement technique is considered to be one of the
     state-of-the-art metrics of explainability.
 
-    This program outputs a JSON file containing the ROAD evaluations (using
+    This program outputs a .json file containing the ROAD evaluations (using
     most-relevant-first, or MoRF, and least-relevant-first, or LeRF for each
-    sample in the datamodule. Values for MoRF and LeRF represent averages by
+    sample in the DataModule. Values for MoRF and LeRF represent averages by
     removing 20, 40, 60 and 80% of most or least relevant pixels respectively
     from the image, and averaging results for all these percentiles.
 
     .. note::
 
-       This application is relatively slow when processing a large datamodule
+       This application is relatively slow when processing a large DataModule
        with many (positive) samples.
     """
     import json
diff --git a/src/mednet/scripts/saliency/evaluate.py b/src/mednet/scripts/saliency/evaluate.py
index f84ee73e1da3bdc89bb4dc3509769e91219e3b72..4b00cc5060850bc684d9f4e25cce842536c1f530 100644
--- a/src/mednet/scripts/saliency/evaluate.py
+++ b/src/mednet/scripts/saliency/evaluate.py
@@ -65,7 +65,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output-folder",
     "-o",
-    help="Path where to store the analysis result (created if does not exist)",
+    help="Directory in which to store the analysis result (created if does not exist)",
     required=False,
     default="results",
     type=click.Path(file_okay=False, dir_okay=True, path_type=pathlib.Path),
diff --git a/src/mednet/scripts/saliency/generate.py b/src/mednet/scripts/saliency/generate.py
index 34e54fd49865821055ed311e271d9f790f72f431..c2ae45015b5f8c901ead4f4be7cb72d81d4f847a 100644
--- a/src/mednet/scripts/saliency/generate.py
+++ b/src/mednet/scripts/saliency/generate.py
@@ -21,7 +21,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
     cls=ConfigCommand,
     epilog="""Examples:
 
-1. Generates saliency maps for all prediction dataloaders on a datamodule,
+1. Generates saliency maps for all prediction dataloaders on a DataModule,
    using a pre-trained DenseNet model, and saves them as numpy-pickeled
    objects on the output directory:
 
@@ -43,9 +43,9 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--datamodule",
     "-d",
-    help="""A lightning data module that will be asked for prediction data
-    loaders. Typically, this includes all configured splits in a datamodule,
-    however this is not a requirement.  A datamodule that returns a single
+    help="""A lightning DataModule that will be asked for prediction data
+    loaders. Typically, this includes all configured splits in a DataModule,
+    however this is not a requirement.  A DataModule that returns a single
     dataloader for prediction (wrapped in a dictionary) is acceptable.""",
     required=True,
     cls=ResourceOption,
@@ -53,7 +53,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output-folder",
     "-o",
-    help="Path where to store saliency maps (created if does not exist)",
+    help="Directory in which to store saliency maps (created if does not exist)",
     required=True,
     type=click.Path(
         exists=False,
diff --git a/src/mednet/scripts/saliency/interpretability.py b/src/mednet/scripts/saliency/interpretability.py
index 321bb18f51ae0c5c8cc6ce834dbb017365527e39..e5fa95564e218cd0afc881d9243053a639049e35 100644
--- a/src/mednet/scripts/saliency/interpretability.py
+++ b/src/mednet/scripts/saliency/interpretability.py
@@ -30,9 +30,9 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--datamodule",
     "-d",
-    help="""A lightning data module that will be asked for prediction data
-    loaders. Typically, this includes all configured splits in a datamodule,
-    however this is not a requirement.  A datamodule that returns a single
+    help="""A lightning DataModule that will be asked for prediction data
+    loaders. Typically, this includes all configured splits in a DataModule,
+    however this is not a requirement.  A DataModule that returns a single
     dataloader for prediction (wrapped in a dictionary) is acceptable.""",
     required=True,
     cls=ResourceOption,
@@ -66,8 +66,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output-json",
     "-o",
-    help="""Path where to store the output JSON file containing all
-    measures.""",
+    help="""Path to the .json file in which all measures will be saved.""",
     required=True,
     type=click.Path(
         file_okay=True,
@@ -98,8 +97,8 @@ def interpretability(
        contain built-in annotations which corroborate classification.
 
 
-    As a result of the evaluation, this application creates a single JSON file
-    that resembles the original datamodule, with added information containing
+    As a result of the evaluation, this application creates a single .json file
+    that resembles the original DataModule, with added information containing
     the following measures, for each sample:
 
     * Proportional Energy: A measure that compares (UNthresholed) saliency maps
diff --git a/src/mednet/scripts/saliency/view.py b/src/mednet/scripts/saliency/view.py
index b61df6e2272542e50f5e6f2435685b105dd5f060..928cac6b75ad6659d3b9993f0e8ed3b241f7d230 100644
--- a/src/mednet/scripts/saliency/view.py
+++ b/src/mednet/scripts/saliency/view.py
@@ -35,14 +35,14 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--datamodule",
     "-d",
-    help="A lightning data module containing the training, validation and test sets.",
+    help="A lightning DataModule containing the training, validation and test sets.",
     required=True,
     cls=ResourceOption,
 )
 @click.option(
     "--input-folder",
     "-i",
-    help="Path to the folder containing the saliency maps for a specific visualization type.",
+    help="Path to the directory containing the saliency maps for a specific visualization type.",
     required=True,
     type=click.Path(
         file_okay=False,
@@ -56,7 +56,7 @@ logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")
 @click.option(
     "--output-folder",
     "-o",
-    help="Path where to store the visualizations (created if does not exist)",
+    help="Directory in which to store the visualizations (created if does not exist)",
     required=True,
     type=click.Path(
         file_okay=False,
diff --git a/src/mednet/scripts/train.py b/src/mednet/scripts/train.py
index de8801af084a589671745883a15fd5bb67b56b6c..cc974870dbc0774f6b41f029736ac7ba79452765 100644
--- a/src/mednet/scripts/train.py
+++ b/src/mednet/scripts/train.py
@@ -35,7 +35,7 @@ def reusable_options(f):
     @click.option(
         "--output-folder",
         "-o",
-        help="Path where to store results (created if does not exist)",
+        help="Directory in which to store results (created if does not exist)",
         required=True,
         type=click.Path(
             file_okay=False,
@@ -56,7 +56,7 @@ def reusable_options(f):
     @click.option(
         "--datamodule",
         "-d",
-        help="A lightning data module containing the training and validation sets.",
+        help="A lightning DataModule containing the training and validation sets.",
         required=True,
         cls=ResourceOption,
     )
@@ -293,9 +293,9 @@ def train(
 
     # If asked, rebalances the loss criterion based on the relative proportion
     # of class examples available in the training set.  Also affects the
-    # validation loss if a validation set is available on the data module.
+    # validation loss if a validation set is available on the DataModule.
     if balance_classes:
-        logger.info("Applying datamodule train sampler balancing...")
+        logger.info("Applying DataModule train sampler balancing...")
         datamodule.balance_sampler_by_class = True
         # logger.info("Applying train/valid loss balancing...")
         # model.balance_losses_by_class(datamodule)
diff --git a/src/mednet/scripts/train_analysis.py b/src/mednet/scripts/train_analysis.py
index 88a6bcb2be9eb0912693831289c28a78404e0e2f..d3c979e0c42c97c85ff3b7f4b085e64a855dea36 100644
--- a/src/mednet/scripts/train_analysis.py
+++ b/src/mednet/scripts/train_analysis.py
@@ -123,7 +123,7 @@ def create_figures(
 @click.option(
     "--output",
     "-o",
-    help="Name of the output file to create (multi-page PDF)",
+    help="Name of the output file to create (multi-page .pdf)",
     required=True,
     show_default=True,
     default="trainlog.pdf",
@@ -135,7 +135,7 @@ def train_analysis(
     output: pathlib.Path,
 ) -> None:
     """Creates a plot for each metric in the training logs and saves them in a
-    PDF file."""
+    .pdf file."""
 
     import matplotlib.pyplot as plt
 
diff --git a/tests/test_cli.py b/tests/test_cli.py
index 6648d1354cce704798a342a00b7554c0b90338d0..64a9e2d5f8bdd9fed55e156fe185f8d9ca20c0ec 100644
--- a/tests/test_cli.py
+++ b/tests/test_cli.py
@@ -87,7 +87,7 @@ def test_config_describe_montgomery():
     runner = CliRunner()
     result = runner.invoke(describe, ["montgomery"])
     _assert_exit_0(result)
-    assert "Montgomery datamodule for TB detection." in result.output
+    assert "Montgomery DataModule for TB detection." in result.output
 
 
 def test_database_help():
diff --git a/src/mednet/engine/predictor.py b/src/mednet/engine/predictor.py
index e4d625fb2aa3ecd2beda9d88ece11d25ce136883..db7b6ac1dd1bd501eea802ffec50265ce7642579 100644
--- a/src/mednet/engine/predictor.py
+++ b/src/mednet/engine/predictor.py
@@ -38,7 +38,7 @@ def run(
     model
         Neural network model (e.g. pasa).
     datamodule
         The lightning datamodule to use for training **and** validation
     device_manager
         An internal device representation, to be used for training and
         validation.  This representation can be converted into a pytorch device
@@ -55,7 +55,7 @@ def run(
     | MultiClassPredictionSplit
     | None
     )
         Depending on the return type of the datamodule's
         ``predict_dataloader()`` method:
 
         * if :py:class:`torch.utils.data.DataLoader`, then returns a
@@ -71,7 +71,7 @@ def run(
     Raises
     ------
     TypeError
-        If the datamodule's ``predict_dataloader()`` method does not return any
+        If the DataModule's ``predict_dataloader()`` method does not return any
         of the types described above.
     """
 
@@ -38,7 +38,7 @@ def run(
         Neural network model (e.g. pasa).
     datamodule
-        The lightning datamodule to use for training **and** validation
+        The lightning DataModule to use for training **and** validation
     device_manager
         An internal device representation, to be used for training and
@@ -55,7 +55,7 @@ def run(
     | None
     )
-        Depending on the return type of the datamodule's
+        Depending on the return type of the DataModule's
         ``predict_dataloader()`` method:
 
diff --git a/src/mednet/scripts/database.py b/src/mednet/scripts/database.py
index 8bd43ff2dd546c9f48da96452a1a3df0144aba29..f58a2746a3656e63a7a0eb9050a82935e05ef964 100644
--- a/src/mednet/scripts/database.py
+++ b/src/mednet/scripts/database.py
@@ -132,7 +132,7 @@ def list():
 )
 @verbosity_option(logger=logger, expose_value=False)
 def check(split, limit):
     """Checks file access on one or more datamodules."""
     import importlib.metadata
     import sys
 
@@ -189,5 +189,5 @@ def check(split, limit):
         )
     else:
         click.secho(
-            f"Found {errors} errors loading datamodule `{split}`.", fg="red"
+            f"Found {errors} errors loading DataModule `{split}`.", fg="red"
         )
@@ -132,7 +132,7 @@ def list():
 @verbosity_option(logger=logger, expose_value=False)
 def check(split, limit):
-    """Checks file access on one or more datamodules."""
+    """Checks file access on one or more DataModules."""
     import importlib.metadata
     import sys